/**
* 文件：TableIndexServiceImpl.java
* 版本：1.0.0
* 日期：
* Copyright &reg; 
* All right reserved.
*/

package com.mortals.xhx.base.system.table.service.impl;

import com.mortals.framework.ap.GlobalSysInfo;
import com.mortals.framework.dao.ICRUDSubmeterDao;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.TableParam;
import com.mortals.framework.service.impl.AbstractCRUDServiceImpl;
import com.mortals.framework.util.DateUtils;
import com.mortals.framework.util.StringUtils;
import com.mortals.xhx.base.system.table.dao.TableIndexDao;
import com.mortals.xhx.base.system.table.model.TableIndexEntity;
import com.mortals.xhx.base.system.table.model.TableIndexQuery;
import com.mortals.xhx.base.system.table.service.TableIndexService;

import org.springframework.stereotype.Service;

import java.util.*;

/**
 * <p>Title: 分表索引信息</p>
 * <p>Description: TableIndexServiceImpl service接口 </p>
 * <p>Copyright: Copyright &reg;  </p>
 * <p>Company: </p>
 * @author 
 * @version 1.0.0
 */
@Service("tableIndexService")
public class TableIndexServiceImpl extends AbstractCRUDServiceImpl<TableIndexDao,TableIndexEntity,Long> implements TableIndexService {


    @SuppressWarnings("rawtypes")
    public boolean createTable(ICRUDSubmeterDao submeterDao, TableParam param) {
        boolean ret = false;
        TableParam retParam = null;
        try {
            retParam = submeterDao.createTable(param);
            if (retParam != null && retParam.tableMap != null && retParam.tableMap.size() > 0) {
                log.info("创建表-->" + retParam.tableMap.keySet());
            }
        } catch (Exception e) {
            log.error("执行创建表任务异常-->" + submeterDao, e);
        }
        if (retParam != null && retParam.tableMap != null && retParam.tableMap.size() > 0) {
            Date currDate = new Date();
            for (Map.Entry<String, String> ee : retParam.tableMap.entrySet()) {
                String tableName = ee.getKey();
                String tableMark = ee.getValue();
                try {
                    TableIndexEntity table = new TableIndexEntity();
                    table.setTableName(tableName);
                    table.setTableMark(tableMark);
                    table.setCreateTime(currDate);
                    dao.insert(table);
                    ret = true;
                } catch (Exception e) {
                    log.error("保存分表索引数据异常，原因：" + e.getMessage());
                }
            }
        }
        return ret;
    }

    /**
     * 查询最近1个月创建的表集合
     * @return
     */
    public Set<String> findLastMonthTables() {
        Set<String> retList = new HashSet<String>();
        try {
            TableIndexQuery params = new TableIndexQuery();
            params.setCreateTimeStart(DateUtils.addMonth(new Date(), -1, "yyyy-MM-dd"));
            List<TableIndexEntity> list = dao.getList(params);
            for (TableIndexEntity entity : list) {
                if (StringUtils.isNotEmpty(entity.getTableName())) {
                    retList.add(entity.getTableName());
                }
            }
        } catch (Exception e) {
            log.error("查询分表索引异常-->" + e.getMessage());
        }
        return retList;
    }
}